* Load OECD data and append Eurostat data
clear all
cd "C:/Users/drechsel/Dropbox/Broadbent et al/restud acceptance/replicationCode/Section2/Replication_Section2_2/"
use "Data OECD/03_regressiondata_OECD.dta"
append using "Data Eurostat/03_regressiondata_Eurostat.dta"

* Units are already consistent between sources:
* GVA is millions (real, national currency), employment is thousands
* In OECD-only data: hours is millions

******** !!! NEED TO BRING INTO THE SAME REAL UNITS !!! ********

* First import nominal exchange rates
gen CountryXrate = Country
replace CountryXrate = "Euro area (19 countries)" if Country == "Austria" | Country == "Belgium" | Country == "Finland" | Country == "France" | ///
						Country == "Germany" | Country == "Greece" | Country == "Ireland" | Country == "Italy" | Country == "Luxembourg" | ///
						Country == "Netherlands" | Country == "Portugal" | Country == "Spain" | Country == "Cyprus" | Country == "Estonia" | ///
						Country == "Latvia" | Country == "Lithuania" | Country == "Slovak Republic" | Country == "Slovenia" | ///
						Country == "Bulgaria" | Country == "Croatia" | Country == "Romania"
* (note that the non-Euro countries from Eurostat have everything expressed in Euros as well: Romania, Bulgaria, Croatia)
* (note that Malta is not here)
* (so this gives 19 + 3 - 1 = 21 countries for which things are expressd in Euros)
merge m:1 CountryXrate quarter using "Data Exchange rates/02_OECD_nominal_xrates_EURO.dta"
drop if _merge == 2
drop _merge
drop CountryXrate
sort Country quarter

* Then import GDP deflators for Canada and Australia, which are used becuase no industry level nominal data available
merge m:1 quarter using "Data Exchange rates/02_GDP_deflators.dta"
drop if _merge == 2
drop _merge
replace CAN_GDP_deflator = . if Country ~= "Canada"
replace AUS_GDP_deflator = . if Country ~= "Australia"

* For OECD data, calculate deflator from nominal and real GVA data 
* (For Eurostat, this is available directly)
gen GVA_B1G_DEFL = GVA_B1G_NOMINAL / GVA_B1G
gen GVA_B1GVA_DEFL = GVA_B1GVA_NOMINAL / GVA_B1GVA 
gen GVA_B1GVB_E_DEFL = GVA_B1GVB_E_NOMINAL / GVA_B1GVB_E
gen GVA_B1GVC_DEFL = GVA_B1GVC_NOMINAL / GVA_B1GVC
gen GVA_B1GVF_DEFL = GVA_B1GVF_NOMINAL / GVA_B1GVF
gen GVA_B1GVG_I_DEFL = GVA_B1GVG_I_NOMINAL / GVA_B1GVG_I
gen GVA_B1GVG_U_DEFL = GVA_B1GVG_U_NOMINAL / GVA_B1GVG_U
gen GVA_B1GVJ_DEFL = GVA_B1GVJ_NOMINAL / GVA_B1GVJ
gen GVA_B1GVK_DEFL = GVA_B1GVK_NOMINAL / GVA_B1GVK
gen GVA_B1GVL_DEFL = GVA_B1GVL_NOMINAL / GVA_B1GVL
gen GVA_B1GVM_N_DEFL = GVA_B1GVM_N_NOMINAL / GVA_B1GVM_N
gen GVA_B1GVO_Q_DEFL = GVA_B1GVO_Q_NOMINAL / GVA_B1GVO_Q
gen GVA_B1GVR_U_DEFL = GVA_B1GVR_U_NOMINAL / GVA_B1GVR_U

* Generate also the German industry level deflators by themselves
gen GVA_B1G_DEFL_GERMAN0 = GVA_B1G_DEFL if Country == "Germany"
gen GVA_B1GVA_DEFL_GERMAN0 = GVA_B1GVA_DEFL if Country == "Germany"
gen GVA_B1GVB_E_DEFL_GERMAN0 = GVA_B1GVB_E_DEFL if Country == "Germany"
gen GVA_B1GVC_DEFL_GERMAN0 = GVA_B1GVC_DEFL if Country == "Germany"
gen GVA_B1GVF_DEFL_GERMAN0 = GVA_B1GVF_DEFL if Country == "Germany"
gen GVA_B1GVG_I_DEFL_GERMAN0 = GVA_B1GVG_I_DEFL if Country == "Germany"
gen GVA_B1GVG_U_DEFL_GERMAN0 = GVA_B1GVG_U_DEFL if Country == "Germany"
gen GVA_B1GVJ_DEFL_GERMAN0 = GVA_B1GVJ_DEFL if Country == "Germany"
gen GVA_B1GVK_DEFL_GERMAN0 = GVA_B1GVK_DEFL if Country == "Germany"
gen GVA_B1GVL_DEFL_GERMAN0 = GVA_B1GVL_DEFL if Country == "Germany"
gen GVA_B1GVM_N_DEFL_GERMAN0 = GVA_B1GVM_N_DEFL if Country == "Germany"
gen GVA_B1GVO_Q_DEFL_GERMAN0 = GVA_B1GVO_Q_DEFL if Country == "Germany"
gen GVA_B1GVR_U_DEFL_GERMAN0 = GVA_B1GVR_U_DEFL if Country == "Germany"

* Add the German deflators as a variable to each line
bysort quarter: egen GVA_B1G_DEFL_GERMAN = max(GVA_B1G_DEFL_GERMAN0)
bysort quarter: egen GVA_B1GVA_DEFL_GERMAN = max(GVA_B1GVA_DEFL_GERMAN0)
bysort quarter: egen GVA_B1GVB_E_DEFL_GERMAN = max(GVA_B1GVB_E_DEFL_GERMAN0)
bysort quarter: egen GVA_B1GVC_DEFL_GERMAN = max(GVA_B1GVC_DEFL_GERMAN0)
bysort quarter: egen GVA_B1GVF_DEFL_GERMAN = max(GVA_B1GVF_DEFL_GERMAN0)
bysort quarter: egen GVA_B1GVG_I_DEFL_GERMAN = max(GVA_B1GVG_I_DEFL_GERMAN0)
bysort quarter: egen GVA_B1GVG_U_DEFL_GERMAN = max(GVA_B1GVG_U_DEFL_GERMAN0)
bysort quarter: egen GVA_B1GVJ_DEFL_GERMAN = max(GVA_B1GVJ_DEFL_GERMAN0)
bysort quarter: egen GVA_B1GVK_DEFL_GERMAN = max(GVA_B1GVK_DEFL_GERMAN0)
bysort quarter: egen GVA_B1GVL_DEFL_GERMAN = max(GVA_B1GVL_DEFL_GERMAN0)
bysort quarter: egen GVA_B1GVM_N_DEFL_GERMAN = max(GVA_B1GVM_N_DEFL_GERMAN0)
bysort quarter: egen GVA_B1GVO_Q_DEFL_GERMAN = max(GVA_B1GVO_Q_DEFL_GERMAN0)
bysort quarter: egen GVA_B1GVR_U_DEFL_GERMAN = max(GVA_B1GVR_U_DEFL_GERMAN0)
drop *_GERMAN0


* AUS and Canada: use GDP deflator as industry deflator because no industry level nominal data available
replace GVA_B1G_DEFL = AUS_GDP_deflator if Country == "Australia"
replace GVA_B1GVA_DEFL = AUS_GDP_deflator if Country == "Australia"
replace GVA_B1GVB_E_DEFL = AUS_GDP_deflator if Country == "Australia"
replace GVA_B1GVC_DEFL = AUS_GDP_deflator if Country == "Australia"
replace GVA_B1GVF_DEFL = AUS_GDP_deflator if Country == "Australia"
replace GVA_B1GVG_I_DEFL = AUS_GDP_deflator if Country == "Australia"
replace GVA_B1GVG_U_DEFL = AUS_GDP_deflator if Country == "Australia"
replace GVA_B1GVJ_DEFL = AUS_GDP_deflator if Country == "Australia"
replace GVA_B1GVK_DEFL = AUS_GDP_deflator if Country == "Australia"
replace GVA_B1GVL_DEFL = AUS_GDP_deflator if Country == "Australia"
replace GVA_B1GVM_N_DEFL = AUS_GDP_deflator if Country == "Australia"
replace GVA_B1GVO_Q_DEFL = AUS_GDP_deflator if Country == "Australia"
replace GVA_B1GVR_U_DEFL = AUS_GDP_deflator if Country == "Australia"
replace GVA_B1G_DEFL = CAN_GDP_deflator if Country == "Canada"
replace GVA_B1GVA_DEFL = CAN_GDP_deflator if Country == "Canada"
replace GVA_B1GVB_E_DEFL = CAN_GDP_deflator if Country == "Canada"
replace GVA_B1GVC_DEFL = CAN_GDP_deflator if Country == "Canada"
replace GVA_B1GVF_DEFL = CAN_GDP_deflator if Country == "Canada"
replace GVA_B1GVG_I_DEFL = CAN_GDP_deflator if Country == "Canada"
replace GVA_B1GVG_U_DEFL = CAN_GDP_deflator if Country == "Canada"
replace GVA_B1GVJ_DEFL = CAN_GDP_deflator if Country == "Canada"
replace GVA_B1GVK_DEFL = CAN_GDP_deflator if Country == "Canada"
replace GVA_B1GVL_DEFL = CAN_GDP_deflator if Country == "Canada"
replace GVA_B1GVM_N_DEFL = CAN_GDP_deflator if Country == "Canada"
replace GVA_B1GVO_Q_DEFL = CAN_GDP_deflator if Country == "Canada"
replace GVA_B1GVR_U_DEFL = CAN_GDP_deflator if Country == "Canada"

* Calculate all variables in real German baskets [EUROSTAT]
* > Take GVA in real national currency
* > Divide by the real exchange rate between each sector and the sector in Germany
* > This real exchange rate is the nominal exchange rate with the Euro multiplied
*   with the ratio of the relevant deflators
gen RRGVA_Agri = GVA_Agri / (CurrencyPerEUR_nominal * GVA_B1GVA_DEFL_GERMAN / GVA_Agri_DEFL)
gen RRGVA_Arts = GVA_Arts / (CurrencyPerEUR_nominal * GVA_B1GVR_U_DEFL_GERMAN / GVA_Arts_DEFL)
gen RRGVA_Cons = GVA_Cons / (CurrencyPerEUR_nominal * GVA_B1GVF_DEFL_GERMAN / GVA_Cons_DEFL)
gen RRGVA_Fina = GVA_Fina / (CurrencyPerEUR_nominal * GVA_B1GVK_DEFL_GERMAN / GVA_Fina_DEFL)
gen RRGVA_Indu = GVA_Indu / (CurrencyPerEUR_nominal * GVA_B1GVB_E_DEFL_GERMAN / GVA_Indu_DEFL)
gen RRGVA_Info = GVA_Info / (CurrencyPerEUR_nominal * GVA_B1GVJ_DEFL_GERMAN / GVA_Info_DEFL)
gen RRGVA_Manu = GVA_Manu / (CurrencyPerEUR_nominal * GVA_B1GVC_DEFL_GERMAN / GVA_Manu_DEFL)
gen RRGVA_Prof = GVA_Prof / (CurrencyPerEUR_nominal * GVA_B1GVM_N_DEFL_GERMAN / GVA_Prof_DEFL)
gen RRGVA_Publ = GVA_Publ / (CurrencyPerEUR_nominal * GVA_B1GVO_Q_DEFL_GERMAN / GVA_Publ_DEFL)
gen RRGVA_Real = GVA_Real / (CurrencyPerEUR_nominal * GVA_B1GVL_DEFL_GERMAN / GVA_Real_DEFL)
gen RRGVA_Tota = GVA_Tota / (CurrencyPerEUR_nominal * GVA_B1G_DEFL_GERMAN / GVA_Tota_DEFL)
gen RRGVA_Whol = GVA_Whol / (CurrencyPerEUR_nominal * GVA_B1GVG_I_DEFL_GERMAN / GVA_Whol_DEFL)

* Calculate all variables in real German baskets [OECD]
gen RRGVA_B1G = GVA_B1G / (CurrencyPerEUR_nominal * GVA_B1G_DEFL_GERMAN / GVA_B1G_DEFL)
gen RRGVA_B1GVA = GVA_B1GVA / (CurrencyPerEUR_nominal * GVA_B1GVA_DEFL_GERMAN / GVA_B1GVA_DEFL)
gen RRGVA_B1GVB_E = GVA_B1GVB_E / (CurrencyPerEUR_nominal * GVA_B1GVB_E_DEFL_GERMAN / GVA_B1GVB_E_DEFL)
gen RRGVA_B1GVC = GVA_B1GVC / (CurrencyPerEUR_nominal * GVA_B1GVC_DEFL_GERMAN / GVA_B1GVC_DEFL)
gen RRGVA_B1GVF = GVA_B1GVF / (CurrencyPerEUR_nominal * GVA_B1GVF_DEFL_GERMAN / GVA_B1GVF_DEFL)
gen RRGVA_B1GVG_I = GVA_B1GVG_I / (CurrencyPerEUR_nominal * GVA_B1GVG_I_DEFL_GERMAN / GVA_B1GVG_I_DEFL)
gen RRGVA_B1GVG_U = GVA_B1GVG_U / (CurrencyPerEUR_nominal * GVA_B1GVG_U_DEFL_GERMAN / GVA_B1GVG_U_DEFL)
gen RRGVA_B1GVJ = GVA_B1GVJ / (CurrencyPerEUR_nominal * GVA_B1GVJ_DEFL_GERMAN / GVA_B1GVJ_DEFL)
gen RRGVA_B1GVK = GVA_B1GVK / (CurrencyPerEUR_nominal * GVA_B1GVK_DEFL_GERMAN / GVA_B1GVK_DEFL)
gen RRGVA_B1GVL = GVA_B1GVL / (CurrencyPerEUR_nominal * GVA_B1GVL_DEFL_GERMAN / GVA_B1GVL_DEFL)
gen RRGVA_B1GVM_N = GVA_B1GVM_N / (CurrencyPerEUR_nominal * GVA_B1GVM_N_DEFL_GERMAN / GVA_B1GVM_N_DEFL)
gen RRGVA_B1GVO_Q = GVA_B1GVO_Q / (CurrencyPerEUR_nominal * GVA_B1GVO_Q_DEFL_GERMAN / GVA_B1GVO_Q_DEFL)
gen RRGVA_B1GVR_U = GVA_B1GVR_U / (CurrencyPerEUR_nominal * GVA_B1GVR_U_DEFL_GERMAN / GVA_B1GVR_U_DEFL)


* Save data
cd "Data Sets Combined/"
save "04_combined_data.dta", replace