* Load the latest data
clear all
set maxvar 25000
cd "C:/Users/drechsel/Dropbox/Broadbent et al/restud acceptance/replicationCode/Section2/Replication_Section2_2"
use "Data Sets Combined/05_SectorCountryTime_panel.dta"

* Set panel
tsset CountrySectorID Quarter

* End in 2016:Q2, because we do not want to overlap with Brexit
keep if Quarter < 226

* Start in 1997:Q2, which is what goes into regressions (Estonia)
keep if Quarter > 148


************** Calculate pre/post means for Figure 2 ***************

preserve 
bysort CountryID Quarter: egen T_growth = mean(D_RRGVAperHoursPatched) if TradedDummy==1
bysort CountryID Quarter: egen N_growth = mean(D_RRGVAperHoursPatched) if TradedDummy==0

collapse *_growth EU* Join* Pre*, by(CountryID Quarter)

egen all_meangrowth_T = mean(T_growth) 
egen all_meangrowth_N = mean(N_growth)

egen joiners_meangrowth_T_pre = mean(T_growth) if (EUjoiner_2004==1 | EUjoiner_2007==1 | EUjoiner_2013==1) & EUmember==0
egen joiners_meangrowth_N_pre = mean(N_growth) if (EUjoiner_2004==1 | EUjoiner_2007==1 | EUjoiner_2013==1) & EUmember==0

egen joiners_meangrowth_T_post = mean(T_growth) if (EUjoiner_2004==1 | EUjoiner_2007==1 | EUjoiner_2013==1) & EUmember==1
egen joiners_meangrowth_N_post = mean(N_growth) if (EUjoiner_2004==1 | EUjoiner_2007==1 | EUjoiner_2013==1) & EUmember==1

collapse *_meangrowth_* 

gen all_countries = all_meangrowth_T - all_meangrowth_N
gen joiners_before_joining = joiners_meangrowth_T_pre - joiners_meangrowth_N_pre
gen joiners_after_joining = joiners_meangrowth_T_post - joiners_meangrowth_N_post

keep all_countries joiners_before_joining joiners_after_joining
export excel using "Figure2_Data.xls", firstrow(variables) keepcellfmt replace

restore

************** Summary stats of GVA growth by country and sector ***************

* Winsorize
winsor D_RRGVAperHoursPatched, p(0.05) gen(D_RRGVAperHoursPatched_w)
replace D_RRGVAperHoursPatched = D_RRGVAperHoursPatched_w

** Country by country: show summary stats across sectors
forvalues i=1/31 {
gen Country_`i' = D_RRGVAperHoursPatched if CountryID==`i'
}
sum2docx Country_* using Appendix_TableA2.docx, replace stats(N mean(%9.2f) sd(%9.2f) p10(%9.2f) median(%9.2f) p90(%9.2f)) 

** Sector by sector: show summary stats across acountries
forvalues i=1/10 {
gen Sector_`i' = D_RRGVAperHoursPatched if SectorID==`i'
}
sum2docx Sector_* using Appendix_TableA1.docx, replace stats(N mean(%9.2f) sd p10(%9.2f) median(%9.2f) p90(%9.2f)) 