* Load the latest data
clear all
set maxvar 25000
cd "C:/Users/drechsel/Dropbox/Broadbent et al/restud acceptance/replicationCode/Section2/Replication_Section2_2/"
use "Data Sets Combined/05_SectorCountryTime_panel.dta"

******************************** SETTINGS **************************************

* Set panel
tsset CountrySectorID Quarter

* LHS variable
gen D_PROD = D_RRGVAperHoursPatched

* End in 2016:Q2, because we do not want to overlap with Brexit
keep if Quarter < 226

* Generate interactions of interest (Quarterly)
gen TradedXJoinEU5 = TradedDummy * JoinEU5

* Generate 3-year interaction for robustness
gen TradedXJoinEU3 = TradedDummy * JoinEU3

* Wider definiion of tradable
gen TradedWideXJoinEU5 = TradedDummyWide * JoinEU5

* Generate random entry dates for each joiner (Placebo test)
set seed 6272022
generate randomquarter = round(runiform(144, 225))
gen randomquarter2 = randomquarter if Quarter==144 & (EUjoiner_1995 == 1 | EUjoiner_2004 == 1 | EUjoiner_2007 == 1 | EUjoiner_2013 == 1) & SectorID==1
bysort CountryID: egen placeboquarter = max(randomquarter2)
drop randomquart*

gen PlaceboJoinEU5 = 0
replace PlaceboJoinEU5 = 1 if placeboquarter~=. & Quarter > placeboquarter-1 & Quarter < placeboquarter+21
gen TradedXPlaceboJoinEU5 = TradedDummy * PlaceboJoinEU5

* Generate also on interaction with joining the Euro Area, for robustness
gen TradedXJoinEURO5 = TradedDummy * JoinEURO5

* Winsorize the LHS
winsor D_PROD, p(0.05) gen(D_PROD_w)
gen D_PROD_nowin = D_PROD
replace D_PROD = D_PROD_w

********************* REGRESSIONS - MAIN ******************************
* Simple reg
reghdfe D_PROD TradedXJoinEU5 TradedDummy JoinEU5, noabsorb vce(cluster CountryID)
outreg2 using "Table1.xls", replace se bdec(3) bracket

* Country FE
reghdfe D_PROD TradedXJoinEU5 TradedDummy JoinEU5, absorb(Country) vce(cluster CountryID)
outreg2 using "Table1.xls", append se bdec(3) bracket

* Sector FE
reghdfe D_PROD TradedXJoinEU5 TradedDummy JoinEU5, absorb(Sector) vce(cluster CountryID)
outreg2 using "Table1.xls", append se bdec(3) bracket

* Quarter FE
reghdfe D_PROD TradedXJoinEU5 TradedDummy JoinEU5, absorb(Quarter) vce(cluster CountryID)
outreg2 using "Table1.xls", append se bdec(3) bracket

* All simple FE + CountrySector FE 
reghdfe D_PROD TradedXJoinEU5 TradedDummy JoinEU5, absorb(Country Sector Quarter CountryID#SectorID) vce(cluster CountryID)
outreg2 using "Table1.xls", append se bdec(3) bracket

* 4b) All simple FE + CountryQuarter FE 
reghdfe D_PROD TradedXJoinEU5 TradedDummy JoinEU5, absorb(Country Sector Quarter CountryID#Quarter) vce(cluster CountryID)
outreg2 using "Table1.xls", append se bdec(3) bracket

* 4c) All simple FE + both twoway FE 
reghdfe D_PROD TradedXJoinEU5 TradedDummy JoinEU5, absorb(Country Sector Quarter CountryID#SectorID CountryID#Quarter) vce(cluster CountryID)
outreg2 using "Table1.xls", append se bdec(3) bracket


********************* REGRESSIONS - PLACEBO ******************************
* Simple reg
reghdfe D_PROD TradedXPlaceboJoinEU5 TradedDummy PlaceboJoinEU5, noabsorb vce(cluster CountryID)
outreg2 using "Appendix_TableA3.xls", replace se bdec(3) bracket

* Country FE
reghdfe D_PROD TradedXPlaceboJoinEU5 TradedDummy PlaceboJoinEU5, absorb(Country) vce(cluster CountryID)
outreg2 using "Appendix_TableA3.xls", append se bdec(3) bracket

* Sector FE
reghdfe D_PROD TradedXPlaceboJoinEU5 TradedDummy PlaceboJoinEU5, absorb(Sector) vce(cluster CountryID)
outreg2 using "Appendix_TableA3.xls", append se bdec(3) bracket

* Quarter FE
reghdfe D_PROD TradedXPlaceboJoinEU5 TradedDummy PlaceboJoinEU5, absorb(Quarter) vce(cluster CountryID)
outreg2 using "Appendix_TableA3.xls", append se bdec(3) bracket

* All simple FE + CountrySector FE 
reghdfe D_PROD TradedXPlaceboJoinEU5 TradedDummy PlaceboJoinEU5, absorb(Country Sector Quarter CountryID#SectorID) vce(cluster CountryID)
outreg2 using "Appendix_TableA3.xls", append se bdec(3) bracket

* 4b) All simple FE + CountryQuarter FE 
reghdfe D_PROD TradedXPlaceboJoinEU5 TradedDummy PlaceboJoinEU5, absorb(Country Sector Quarter CountryID#Quarter) vce(cluster CountryID)
outreg2 using "Appendix_TableA3.xls", append se bdec(3) bracket

* 4c) All simple FE + both twoway FE 
reghdfe D_PROD TradedXPlaceboJoinEU5 TradedDummy PlaceboJoinEU5, absorb(Country Sector Quarter CountryID#SectorID CountryID#Quarter) vce(cluster CountryID)
outreg2 using "Appendix_TableA3.xls", append se bdec(3) bracket

******************************* ROBUSTNESS  ******************************

* Repeat last column of main table
reghdfe D_PROD TradedXJoinEU5 TradedDummy JoinEU5, absorb(Country Sector Quarter CountryID#SectorID CountryID#Quarter) vce(cluster CountryID)
outreg2 using "Appendix_TableA4.xls", replace se bdec(3) bracket

* Non-winsorized
reghdfe D_PROD_nowin TradedXJoinEU5 TradedDummy JoinEU5, absorb(Country Sector Quarter CountryID#SectorID CountryID#Quarter) vce(cluster CountryID)
outreg2 using "Appendix_TableA4.xls", append se bdec(3) bracket

* 3 Year version (h=12)
reghdfe D_PROD TradedXJoinEU3* TradedDummy JoinEU3*, absorb(Country Sector Quarter CountryID#SectorID CountryID#Quarter) vce(cluster CountryID)
outreg2 using "Appendix_TableA4.xls", append se bdec(3) bracket

* TradedSector Wide
reghdfe D_PROD TradedWideXJoinEU5 TradedDummyWide JoinEU5, absorb(Country Sector Quarter CountryID#SectorID CountryID#Quarter) vce(cluster CountryID)
outreg2 using "Appendix_TableA4.xls", append se bdec(3) bracket

* EU COUNTRIES ONLY 
preserve
drop if Country == "Canada" | Country == "Australia" | Country == "Norway" | Country == "Switzerland"
reghdfe D_PROD TradedXJoinEU5 TradedDummy JoinEU5, absorb(Country Sector Quarter CountryID#SectorID CountryID#Quarter) vce(cluster CountryID)
outreg2 using "Appendix_TableA4.xls", append se bdec(3) bracket
restore

* Include Euro Area Joining 
reghdfe D_PROD TradedXJoinEU5 TradedXJoinEURO5 TradedDummy JoinEU5 JoinEURO5, absorb(Country Sector Quarter CountryID#SectorID CountryID#Quarter) vce(cluster CountryID)
outreg2 using "Appendix_TableA4.xls", append se bdec(3) bracket

* Countries with hours data only 
preserve
drop if NoHoursData==1

reghdfe D_PROD TradedXJoinEU5 TradedDummy JoinEU5, absorb(Country Sector Quarter CountryID#SectorID CountryID#Quarter) vce(cluster CountryID)
outreg2 using "Appendix_TableA4.xls", append se bdec(3) bracket

restore