% analyse estimation results
close all
clear all
clc

dynarePath = 'c:/dynare/4.5.7/matlab';
addpath(dynarePath);

%% Data Plots for Appendix

endDate=datenum('2019Q4','yyyyQQ');
refDateQ=datenum('2016Q2','yyyyQQ');
set(0,'DefaultTextInterpreter','latex');
set(0, 'DefaultFigureRenderer', 'painters');
oneByOne = [0 0 21 11];

fontsize=9;
[LSLR]=xlsread('BrexitPaperData.xlsx','Shares','D5:E22')';
[CTS]=xlsread('BrexitPaperData.xlsx','Shares','C5:C26')';

t=1997:1:2018;
h(1)=figure('Name','Shares (over time)');
plot2=plot(t,[[LSLR(1,:) nan(1,4)];[LSLR(2,:)] nan(1,4)]);
set(plot2(1),'Color',[0 0.4470 0.7410],'linestyle','-','LineWidth',1.5);
set(plot2(2),'Color',[0.8500 0.3250 0.0980],'linestyle','-.','LineWidth',1.5);
hold on
plot1=plot(t,CTS); grid on;
set(plot1(1),'Color',[0.9290 0.6940 0.1250],'linestyle',':','LineWidth',1.5);
ylabel('Shares');
axis('tight')
ylim([0.55 0.85])
legend({'Labour Share in $T$','Labour Share in $N$','Consumption $T$ Share'},'Location','southwest','Fontsize',10,'interpreter','latex')
legend boxoff  
set(gca,'FontSize',fontsize,'LineWidth',1);
set(h(1),'PaperUnits','centimeters','PaperPosition',oneByOne);
print(h(1),'../Figures/Shares','-depsc2','-r600');
%print(h(1),'../Figures/Shares','-dpdf','-r600');

[GVA]=xlsread('BrexitPaperData.xlsx','GrowthRates','C9:D124');
startDate=datenum('1991Q1','yyyyQQ');
xData=linspace(startDate,endDate,size(GVA,1));
h(2)=figure('Name','GVA');
plot3=plot(xData,GVA'); grid on;
datetick('x','yyyyQQ');
set(plot3(1),'Color',[0 0.4470 0.7410],'LineWidth',1.5,'linestyle','-');
set(plot3(2),'Color',[0.8500 0.3250 0.0980],'LineWidth',1.5,'linestyle','-.');
legend({'GVA in $T$','GVA in $N$'},'Location','southwest','Fontsize',10,'interpreter','latex')
hold on
yLimits=get(gca,'YLim');
p=patch([refDateQ max(xData) max(xData) refDateQ],[yLimits(1) yLimits(1) yLimits(2) yLimits(2)],'c');
set(p,'FaceAlpha',0.2);
uistack(p, 'bottom');
text(refDateQ-400,-6,'Referendum','HorizontalAlignment','center','color','k','Fontsize',10);
hold on
ylabel('YoY Change (\%)');
axis('tight')
legend boxoff  
set(gca,'FontSize',fontsize,'LineWidth',1);
set(h(2),'PaperUnits','centimeters','PaperPosition',oneByOne);
print(h(2),'../Figures/GVA','-depsc2','-r600');
%print(h(2),'../Figures/GVA','-dpdf','-r600');
hold off

[Cons]=xlsread('BrexitPaperData.xlsx','GrowthRates','E9:F124');
startDate=datenum('1991Q1','yyyyQQ');
xData=linspace(startDate,endDate,size(Cons,1));
h(3)=figure('Name','Consumption');
plot4=plot(xData,Cons'); grid on;
datetick('x','yyyyQQ');
set(plot4(1),'Color',[0 0.4470 0.7410],'LineWidth',1.5,'linestyle','-');
set(plot4(2),'Color',[0.8500 0.3250 0.0980],'LineWidth',1.5,'linestyle','-.');
legend({'Consumption in $T$','Consumptoin in $N$'},'Location','southwest','Fontsize',10,'interpreter','latex')
hold on
yLimits=get(gca,'YLim');
p=patch([refDateQ max(xData) max(xData) refDateQ],[yLimits(1) yLimits(1) yLimits(2) yLimits(2)],'c');
set(p,'FaceAlpha',0.2);
uistack(p, 'bottom');
text(refDateQ-400,-6,'Referendum','HorizontalAlignment','center','color','k','Fontsize',10);
hold on
ylabel('YoY Change (\%)');
axis('tight')
legend boxoff  
set(gca,'FontSize',fontsize,'LineWidth',1);
set(h(3),'PaperUnits','centimeters','PaperPosition',oneByOne);
print(h(3),'../Figures/Consumption','-depsc2','-r600');
%print(h(3),'../Figures/Consumption','-dpdf','-r600');
hold off

[Classification,Industries]=xlsread('BrexitPaperData.xlsx','ClassPlot','F2:N107');

CumGVA=num2str(round(Classification([10,20,30,40,50,60,70,80,90,100],9),2));

h(5)=figure('Name','InDustry Classification');
b=bar(Classification(:,1:7),'stacked');
b(7).LineWidth = 1;
b(7).FaceColor = [0 0.4470 0.7410];
b(7).EdgeColor = [0 0.4470 0.7410];
b(3).LineWidth = 1;
b(3).FaceColor = [0.9290 0.6940 0.1250];
b(3).EdgeColor = [0.9290 0.6940 0.1250];
b(2).LineWidth = 1;
b(2).FaceColor = [0.8500 0.3250 0.0980];
b(2).EdgeColor = [0.8500 0.3250 0.0980];
b(4).LineWidth = 1;
b(4).FaceColor = [0.4660 0.6740 0.1880];
b(4).EdgeColor = [0.4660 0.6740 0.1880];
b(6).LineWidth = 1;
b(6).FaceColor = [0.3010 0.7450 0.9330];
b(6).EdgeColor = [0.3010 0.7450 0.9330];
b(5).LineWidth = 1;
b(5).FaceColor = [0.4940 0.1840 0.5560];
b(5).EdgeColor = [0.4940 0.1840 0.5560];
b(1).LineWidth = 1;
b(1).FaceColor = [0.6350 0.0780 0.1840];
b(1).EdgeColor = [0.6350 0.0780 0.1840];
xlim=get(gca,'xlim');hold on;
xlim(2)=105;
axis([1 105 0 1]);
grid on;
plot(xlim,[0.1 0.1],'k','linewidth',2)
ylabel('Final Demand')
xlabel('Cumulative GVA')
set(gca,'xticklabel',CumGVA);
hold off
set(gca,'FontSize',fontsize,'LineWidth',1);
legend({Industries{1:7},'Cut-off'},'Location','northwest')
legend boxoff
set(h(5),'PaperUnits','centimeters','PaperPosition',oneByOne);
print(h(5),'../Figures/IndClass','-depsc2','-r600');
%print(h(5),'../Figures/IndClass','-dpdf','-r600');
