% This program computes the steady state of the model with tradable and
% non-tradable goods. The computation of the SS uses a solver in order to
% match great ratios as well as the fact that T consumption in aggregate
% consumption is 0.6.

% (c) Broadbent, Di Pace, Drechsel, Harrison and Tenreyro (2021)
% 09 September 2021

function [ys,check] =soetnt_steadystate(ys,exe)

global M_
%% /!\ DESCRIPTION OF THE FUNCTION /!\

%% /!\ DO NOT CHANGE THIS PART /!\

%%

%% Here I load the values of the deep parameters in a loop.
%
NumberOfParameters = M_.param_nbr;                            % Number of deep parameters.
for i = 1:NumberOfParameters                                  % Loop...
    paramname = deblank(M_.param_names(i,:));                   %    Get the name of parameter i.
    eval([ paramname ' = M_.params(' int2str(i) ');']);         %    Get the value of parameter i.
end                                                           % End of the loop.
check = 0;

%% END OF THE FIRST MODEL INDEPENDENT BLOCK.
%%
%% THIS BLOCK IS MODEL SPECIFIC.
%%
%% Here the user has to define some parameters and the steady state.
%%
%% CALCULATING THE STEADY STATE VALUES
% Endogenous Variables

p=1;
cbeta=1/((1+crf)*cgat^(-cgamma));
nn=cnn;
nt=cnt;
rf=crf;
gazt=cgat;
cgazt=cgat;
gat=cgat;
gan=cgan;
rh=1/(cbeta*(cgat^(-cgamma)))-1;
rkt=1/(cbeta*cgat^(-cgamma))-(1-cdeltat);
rkn=1/(cbeta*cgat^(-cgamma))-(1-cdeltan);    
cgoy=1-cioy-ctby-ccoy;
ytoy=czeta*ccoy+czeta*cioy+ctby;
ynoy=(1-czeta)*ccoy+(1-czeta)*cioy+cgoy;
calpn=cioy/(calphton*ytoy/rkt*(cgat-(1-cdeltat))+ynoy/rkn*(cgat-(1-cdeltan)));
calpt=calphton*calpn;
yt=(calpt/rkt)^(calpt/(1-calpt))*gat*cnt;
y=yt/ytoy;
yn=ynoy*y;
gazn=(cgan/(cgat^(calpn)))^(1/(1-calpn));
cgazn=gazn;
an=(yn/(gazn*cnn))^(1-calpn)*(rkn/calpn)^calpn;
can=an;
kt=calpt*yt/rkt;
kn=calpn*yn/rkn;
c=ccoy*y;
iv=cioy*y;
cgyn=cgoy*y/yn;
ivt=czeta*iv;
ivn=(1-czeta)*iv;
ct=czeta*c;
cn=(1-czeta)*c;
wt=(1-calpt)*yt/cnt;
wn_p=(1-calpn)*yn/cnn;
c=(czeta^(1+csigma)*ct^(-csigma)+(1-czeta)^(1+csigma)*cn^(-csigma))^(-1/csigma);
wn=wn_p*p;
cbf=ctby*y*(1+rf)/((1+rf)-cgat);
bf=cbf;
tb=ctby*y;
iv=ivt+p*ivn;
cthetan=wn*(1-czeta)^(1+csigma)*(cn/c)^(-csigma-1)/(nn^(comegan-1));
cthetat=wt*czeta^(1+csigma)*(ct/c)^(-csigma-1)/(nt^(comegat-1));
lambda=(c-cthetan/comegan*nn^comegan-cthetat/comegat*nt^comegat)^(-cgamma)*czeta^(1+csigma)*(ct/c)^(-csigma-1);
pc=(czeta+(1-czeta)*p^(csigma/(csigma+1)))^((csigma+1)/csigma);

rer=pc;
rer_ss=rer;
bh=0;
gat=cgat;
gan=cgan;
mu=1;
eps=1;
nu=1;
cbf=bf;
at=1;
s=1;
n=nt+nn;
yt_nt=yt/nt;
yn_nn=yn/nn;
shyty=yt/(yt+p*yn);

%% Observables
DlogYT=log(cgat);
DlogYN=log(cgan);
DlogYY=log(shyty*cgat+(1-shyty)*cgan);
DlogP=log(cgat/cgan);
DlogPA=4*DlogP;
DlogQ=log(1);
logQ=log(1);
NN=log(1);
NT=log(1);
N=log(1);
DlogYN_NN=log(cgan);
DlogYT_NT=log(cgat);
TB_Y=tb/y;
I_Y=iv/y;
C_Y=c/y;
Robs1=0;
Robs2=0;


%% Third I assigan long run levels (Xstars) to the endogenous variables.

%%
%% END OF THE MODEL SPECIFIC BLOCK.
%%
%% DO NOT CHANGE THIS PART.
%%
%% Here I put the steady state levels in the vector ys
%%

ys=NaN*ones(M_.orig_endo_nbr,1);
for idyyy=1:1:M_.orig_endo_nbr, %number of endogenous variables
    define_string=['ys(',num2str(idyyy), ') =',M_.endo_names(idyyy,:)];
    evalc(define_string);
    %define_string2=['ys(',sprintf('%20.6g',idyyy),')=',M_.endo_names(idyyy,:),';'];
    %disp(define_string2)
end

if any(isnan(ys)) || any(isinf(ys)) || any(~isreal(ys))
    check=1;
end

% NumberOfEndogenousVariables = M_.endo_nbr;                    % Number of endogenous variables.
%
% ys = zeros(NumberOfEndogenousVariables,1);                    % Initialization of ys (steady state).
%
% for i = 1:NumberOfEndogenousVariables                         % Loop...
%
%     varname = deblank(M_.endo_names(i,:));                      %    Get the name of endogenous variable i.
%
%     eval(['ys(' int2str(i) ') = ' varname ';']);                %    Get the steady state value of this variable.
%
% end                                                           % End of the loop.

%%
%% Finally I update parameters in the global workspace
%%

id1 = strmatch('cbeta',M_.param_names,'exact');                    % Get the index of A in M_.params
M_.params(id1) = cbeta;
id2 = strmatch('cbf',M_.param_names,'exact');                    % Get the index of A in M_.params
M_.params(id2) = cbf;   
id3 = strmatch('cthetat',M_.param_names,'exact');                    % Get the index of A in M_.params
M_.params(id3) = cthetat;   
id4 = strmatch('cthetan',M_.param_names,'exact');                    % Get the index of A in M_.params
M_.params(id4) = cthetan;    
id5 = strmatch('calpt',M_.param_names,'exact');                    % Get the index of A in M_.params
M_.params(id5) = calpt;   
id6 = strmatch('calpn',M_.param_names,'exact');                    % Get the index of A in M_.params
M_.params(id6) = calpn;   
id7 = strmatch('cgyn',M_.param_names,'exact');                    % Get the index of A in M_.params
M_.params(id7) = cgyn;   
id8 = strmatch('cgoy',M_.param_names,'exact');                    % Get the index of A in M_.params
M_.params(id8) = cgoy;   
id9 = strmatch('rer_ss',M_.param_names,'exact');                    % Get the index of A in M_.params
M_.params(id9) = rer_ss;  
id10 = strmatch('can',M_.param_names,'exact');                    % Get the index of A in M_.params
M_.params(id10) = can;  
id11 = strmatch('cgazn',M_.param_names,'exact');                    % Get the index of A in M_.params
M_.params(id11) = cgazn;
id12 = strmatch('cgazt',M_.param_names,'exact');                    % Get the index of A in M_.params
M_.params(id12) = cgazt; 
%%
%% END OF THE SECOND MODEL INDEPENDENT BLOCK.