function do_Brexit_sim_variant(shockVariant,simOptions)

%% ENSURE ACCESS TO DYNARE OUTPUTS (GLOBAL VARIABLES)
global M_ oo_;

%% UNPACK OPTIONS
resultsFolder = simOptions.resultsFolder;
saveResults = simOptions.saveResults;

% Optional options
if ~isfield(simOptions,'cleanFolder')
    cleanFolder = false;
else
    cleanFolder = simOptions.cleanFolder;
end

%% FIXED PARAMETERS/OPTIONS
dynareModFileName = 'doBrexitSimDynare' ; 
simName = 'BrexitSimulation';

%% SHOCK VARIANT
additionalStub = ['_' shockVariant];

switch shockVariant
    case 'baseline'
        shockVariantTextToWrite = {'rhoPersist = 0.95;';
            'shockVariant = ''baseline'';';};
        additionalStub = '';
    case 'LessPersistent'
        shockVariantTextToWrite = {'rhoPersist = 0.9;';
            'shockVariant = ''LessPersistent'';';};
    case 'Ant20qtr'
        shockVariantTextToWrite = {'rhoPersist = 0.95;';
            'shockVariant = ''Ant20qtr''';};
    case 'Ant10qtr'
        shockVariantTextToWrite = {'rhoPersist = 0.95;';
            'shockVariant = ''Ant10qtr''';};
    case 'gaNshock'
        shockVariantTextToWrite = {'rhoPersist = 0.95;';
            'shockVariant = ''gaNshock''';};
    case 'LevelShock'
        shockVariantTextToWrite = {'rhoPersist = 0.95;';
            'shockVariant = ''LevelShock''';};
    otherwise
        error('Shock variant not supported.');
end

% Create the file that controls shock specification
fileID = fopen('setShockInfo.mod','w'); 
if fileID == -1
    error('Could not open file.');
end
nLines = size(shockVariantTextToWrite,1);
for iLine = 1:nLines
    iText = shockVariantTextToWrite{iLine,1};
    fprintf(fileID,'%s\n',iText);
end
fclose(fileID);

%% CALL DYNARE
dynare(dynareModFileName);

%% PACK AND SAVE RESULTS
if saveResults
    resultsFileName = [simName additionalStub];
    
    % Create cell array of variable names
    nVars = size(M_.endo_names,1);
    endogVarNames = cell(nVars,1);
    if iscell(M_.endo_names(1,:))
        extractCellContents = true;
    else
        extractCellContents = false;
    end
    for iVar = 1:nVars
        if extractCellContents
            endogVarNames{iVar,1} = strtrim(M_.endo_names{iVar});
        else
            endogVarNames{iVar,1} = strtrim(M_.endo_names(iVar,:));
        end
    end
    
    % Extract dynare outputs
    xSim = oo_.endo_simul;
    param_names = M_.param_names;
    param_vals = M_.params;
    
    save([resultsFolder resultsFileName '.mat'],'endogVarNames','xSim',...
        'param_names','param_vals');
end

%% CLEAN THE FOLDER IF REQUIRED
if cleanFolder
    dirInfo = dir(pwd);
    nFiles = size(dirInfo,1);
    fullDynareFileName = [dynareModFileName '.mod'];
    for iFile = 1:nFiles
        iFileName = dirInfo(iFile).name;
        if contains(iFileName,dynareModFileName)    
            if dirInfo(iFile).isdir
                rmdir(iFileName,'s');
            elseif ~strcmpi(iFileName,fullDynareFileName)
                delete(iFileName);
            end
        end
    end
end

end