function detrendedSeries = extract_full_sample_detrended_data(allData,...
        dataNames,varsToDetrend,detrendingInfo)

%% UNPACK OPTIONS
detrendEndDate = detrendingInfo.detrendEndDate;
detrendStartDate = detrendingInfo.detrendStartDate;
detrendType = detrendingInfo.detrendType;

%% OPTIONS (FIXED) IF HAMILTON FILTER IS USED
projHorizon = 8;
nLags = 4;

%% INTERROGATE INPUTS
TT = (1:size(allData,1))';
varInds = lookup_model_index_numbers(dataNames,varsToDetrend);
nVarsToDetrend = size(varInds,1);

useHamiltonFilter = false;
useHPfilter = false;

%% CREATE REGRESSORS FOR THE LINEAR DETRENDING
tt = (detrendStartDate:detrendEndDate)';
switch detrendType
    case 'linear'
        x = [1+0*tt, tt];
        X = [1+0*TT, TT];
    case 'preferred'
        % Add level shift dummy for post GFC data
        GFCdummyStartDate = detrendingInfo.GFCdummyStartDate;
        GFCdummy = 0*tt;
        GFCdummy(tt>=GFCdummyStartDate) = 1;
        GFCdummyT = 0*TT;
        GFCdummyT(TT>=GFCdummyStartDate) = 1;
        x = [1+0*tt, tt, GFCdummy];
        X = [1+0*TT, TT, GFCdummyT];
    case 'HP'
        useHPfilter = true;
    case 'hamilton'
        useHamiltonFilter = true;
end

%% INITIALISE RESULTS STRUCTURE
detrendedSeries = struct;

if useHamiltonFilter
    nanPad = nan(nLags+projHorizon-1,1);
    for iVar = 1:nVarsToDetrend
        iVarMnem = varsToDetrend{iVar};
        iVarInd = varInds(iVar);
        Y = allData(:,iVarInd);
        [trend,residual] = hamilton(Y,projHorizon,nLags);
        %% LOAD INTO STRUCTURE
        detrendedSeries.(iVarMnem).trend = [nanPad; trend];
        detrendedSeries.(iVarMnem).residual = [nanPad; residual];
        detrendedSeries.(iVarMnem).rawData = Y;
    end
elseif useHPfilter
    nanPad = nan(detrendStartDate-1,1);
    for iVar = 1:nVarsToDetrend
        iVarMnem = varsToDetrend{iVar};
        iVarInd = varInds(iVar);
        Y = allData(detrendStartDate:end,iVarInd);
        [trend,residual] = hpfilter(Y,1600);
        %% LOAD INTO STRUCTURE
        detrendedSeries.(iVarMnem).trend = [nanPad; trend];
        detrendedSeries.(iVarMnem).residual = [nanPad; residual];
        detrendedSeries.(iVarMnem).rawData = [detrendStartDate; Y];
    end
else
    %% LOOP OVER SERIES AND DETREND
    % Lower case (y and x) denote dependent variable and regressors over
    % detrending sample (ie before referendum). Upper case letters (Y and X)
    % denote these variables over the full data sample (including
    % post-referendum).
    for iVar = 1:nVarsToDetrend
        iVarMnem = varsToDetrend{iVar};
        iVarInd = varInds(iVar);
        Y = allData(:,iVarInd);
        y = Y(tt); % Pre-referendum data to be detrended
        
        %% RUN REGRESSION
        beta = (x'*x)\(x'*y);
        
        %% EXTRACT RESIDUALS OVER FULL SAMPLE
        trend = X*beta;
        residual = Y - trend;
        
        %% LOAD INTO STRUCTURE
        detrendedSeries.(iVarMnem).trend = trend;
        detrendedSeries.(iVarMnem).residual = residual;
        detrendedSeries.(iVarMnem).rawData = Y;
    end
end

end