function [trend,cycle]=hamilton(y,h,p)

% Regression-based filter suggested by Hamilton (2017):
% "Why You Should Never Use the Hodrick-Prescott Filter"
% Model is y_{t+h} = beta_0 + beta_1 y_t + ... + beta_p y_{t-p+1} + v_{t+h}
% Fitted values give the trend, residuals give the cyclical component
% Will lose p-1+h lags in the original data series 
% Hamilton recommends h=8, p=4 

T=size(y,1);

% Create lags and leads of series
yplush = y(h+1:end,:);
ylags = nan(T,p-1);
for ii=1:p-1   
   ylags(ii+1:end,ii) = y(1:end-ii);  
end

% Align
yplush=yplush(p:T-h,:);
y=y(p:T-h,:);
ylags=ylags(p:T-h,:);

% Run regression and compute fit and residuals
Y = yplush;
X = [ones(T-h-p+1,1) y ylags];
beta = inv(X'*X)*X'*Y;
trend = X*beta;
cycle = Y - X*beta;



