function figHandles = plot_simulation_results(comparatorModel,...
    plotVarInfo,varDetrendingInfo,figurePath,saveFigures,resultsFolder,...
    plotOptions)

%% RELATIVELY HARDWIRED OPTIONS
resultsFileBaseStub = 'BrexitSimulation';
nPanelsPerFigure = 8;
newBlue = [0,0.447,0.741];
newRed = [0.85,0.325,0.098];
basePatchDateInfo = [1 14 14 1];
panelLabels = {'A: ';'B: ';'C: ';'D: ';'E: ';'F: ';'G: ';'H: '};
overRideSomeAxes = false;

%% UNPACK OTHER OPTIONS
nPreShockPeriods = plotOptions.nPreShockPeriods;
plotHorizon = plotOptions.nPostShockPeriods + nPreShockPeriods + 1;
varMnems = plotVarInfo(:,1);
varNames = plotVarInfo(:,2);

if isfield(plotOptions,'fontSize')
    fontSize = plotOptions.fontSize;
else
    fontSize = 10;
end

if isfield(plotOptions,'tickGap')
    overWriteTicks = true;
    tickGap = plotOptions.tickGap;
else
    overWriteTicks = false;
end

if isfield(plotOptions,'plotForSlides')
    if plotOptions.plotForSlides
        plotForSlides = true;
    else
        plotForSlides = false;
    end
else
    plotForSlides = false;
end
if plotForSlides
    nCols = 4;
    figDims = [0 0 19 9.5]; % [0 0 14 10];
    slidesStub = '_slides';
else
    nCols = 2;
    figDims = [0 0 10 14];
    slidesStub = '';
end

nRows = nPanelsPerFigure/nCols;

shockIsLevelShock = false;

%% ANALYSE INPUTS
nVars = size(plotVarInfo,1);
nFigures = nVars/nPanelsPerFigure;
if ceil(nFigures)~=floor(nFigures)
    error(['The must be an exact multiple of ' num2str(nPanelsPerFigure) ...
        ' variables to be plotted.']);
end

%% LOAD THE SIMULATION OUTPUT
load([resultsFolder resultsFileBaseStub '.mat'],'xSim','endogVarNames');
xSimBase = xSim;

%% EXTRACT THE TRANSFORMED PATHS
simBase = extract_simulation_paths(varDetrendingInfo,endogVarNames,...
    xSim,nPreShockPeriods);

%% LOAD THE ALTERNATIVE VARIANT
switch comparatorModel
    case 'none'
        plotAltSim = false;
        figStub = '';
        axisOverRideInfo ={'nn',[-1,1];
                           'nt',[-1,1];
                           'n',[-1,1];
                           'modelTB_y',[0,2]};
        overRideSomeAxes = true;
    otherwise
        plotAltSim = true;
        altSimFileName = ...
            [resultsFolder resultsFileBaseStub '_' comparatorModel '.mat'];
        load(altSimFileName,'xSim','endogVarNames');
        xSimAlt = xSim;
        simAlt = extract_simulation_paths(varDetrendingInfo,endogVarNames,...
            xSim,nPreShockPeriods);
        figStub = comparatorModel;
end

%% LOAD ADDITIONAL DATA FOR PANEL 1 OF FIGURE PART 1 WHERE NECESSARY
switch comparatorModel
    case 'gaNshock'
        ganDetrendingInfo = {'gan', 'minus1times400', 'gan'};
        panelAsimAlt = extract_simulation_paths(ganDetrendingInfo,...
            endogVarNames,xSimAlt,nPreShockPeriods);
    case 'LevelShock'
        AtIndex = lookup_model_index_numbers(endogVarNames,'at');
        AtBase = xSimBase(AtIndex,:)/xSimBase(AtIndex,1);
        AtAlt = xSimAlt(AtIndex,:)/xSimAlt(AtIndex,1);
        gatIndex = lookup_model_index_numbers(endogVarNames,'gat');
        gatBase = xSimBase(gatIndex,:);
        
        gatBGPath = gatBase(1)*ones(1,size(gatBase,2));
        XTBGP = cumprod(gatBGPath);
        XTlagBGP = XTBGP(2:end);
        XTlagBGP(end+1) = XTlagBGP(end);
 
        XTbase = compute_lag_productivity_level('gat',endogVarNames,...
            xSimBase,nPreShockPeriods);
        XTalt = compute_lag_productivity_level('gat',endogVarNames,...
            xSimAlt,nPreShockPeriods);
        XTATbase = AtBase.*XTbase;
        XTATalt = AtAlt.*XTalt;
        shockIsLevelShock = true;
end

%% SET LEGEND STRINGS
switch comparatorModel
    case 'none'
        legendStrings = {'No Brexit baseline';'Benchmark Brexit scenario'};
    case 'Ant10qtr'
        legendStrings = {'No Brexit baseline';'Benchmark Brexit scenario';...
            'Ten quarter anticipation'};
    case 'Ant20qtr'
        legendStrings = {'No Brexit baseline';'Benchmark Brexit scenario';...
            'Twenty quarter anticipation'};
    case 'LessPersistent'
        legendStrings = {'No Brexit baseline';'Benchmark Brexit scenario';...
            'Less persistent variant'};
	case 'LevelShock'
        legendStrings = {'No Brexit baseline';'Benchmark Brexit scenario';...
            'Tradable sector productivity level shock'};
	case 'gaNshock'
        legendStrings = {'No Brexit baseline';'Benchmark Brexit scenario';...
            'Non-tradable productivity growth shock'};
    otherwise
        error('Metadata for comparator model has not been specified.');
end


%% ANALYSE AXIS OVER-RIDE INFO IF NECESSARY
if overRideSomeAxes
    axisOverRideMnems = axisOverRideInfo(:,1);
    axisOverRideVals = axisOverRideInfo(:,2);
end

%% DATES AND TICK MARK OVERWRITE
simDates = (1:plotHorizon)-(nPreShockPeriods+1);
if overWriteTicks
    tickMarks = simDates(1):tickGap:simDates(end);
end

%% DO THE LOOPS
figHandles = cell(nFigures,1);
legHandles = cell(nFigures,1);
varCount = 1;
for iFig = 1:nFigures
    figHandles{iFig,1} = figure;
    for jVar = 1:nPanelsPerFigure
        subplot(nRows,nCols,jVar);
        hold on;
        jVarMnem = varMnems{varCount};
        if varCount == 1 && shockIsLevelShock
            jBGPath = 100*log(XTlagBGP);
            jSimPath = 100*log(XTATbase);
        else
            jBGPath = simBase.(jVarMnem).BGPath;
            jSimPath = simBase.(jVarMnem).simPath;
        end
        plot(simDates,jBGPath(1:plotHorizon),'k--','linewidth',2);
        plot(simDates,jSimPath(1:plotHorizon),'linestyle','-',...
            'color',newBlue,'Linewidth',2);
        if plotAltSim
            if varCount == 1
                switch comparatorModel
                    case 'gaNshock'
                        jAltBGPpath = panelAsimAlt.gan.BGPath;
                        plot(simDates,jAltBGPpath(1:plotHorizon),...
                            'k--','linewidth',2);
                        jAltPath = panelAsimAlt.gan.simPath;
                        titleString = [panelLabels{jVar} ...
                            'Sectoral productivity growth rates'];
                    case 'LevelShock'
                        jAltPath = 100*log(XTATalt);
                         titleString = [panelLabels{jVar} ...
                            'Tradable sector productivity level'];
                    otherwise
                        jAltPath = simAlt.(jVarMnem).simPath;
                        titleString = ...
                            [panelLabels{jVar} varNames{varCount}];
                end
            else
                jAltPath = simAlt.(jVarMnem).simPath;
                titleString = [panelLabels{jVar} varNames{varCount}];
            end
            plot(simDates,jAltPath(1:plotHorizon),'linestyle','-.',...
                'color',newRed,'Linewidth',2);     
        else
            titleString = [panelLabels{jVar} varNames{varCount}];
        end
        title(titleString);
        
        % Finesse...
        axis tight;
        yLimits = get(gca,'YLim');
        if yLimits(1) > 0
            yLimits(1) = yLimits(1)*0.9;
        else
            yLimits(1) = yLimits(1)*1.1;
        end
        if yLimits(2) > 0
            yLimits(2) = yLimits(2)*1.1;
        else
            yLimits(2) = yLimits(2)*0.9;
        end
        % Deal with manual axis over-ride
        if overRideSomeAxes
            try
                overRideVarInd = ...
                    lookup_model_index_numbers(axisOverRideMnems,jVarMnem);
                yLimits = axisOverRideVals{overRideVarInd};
            catch
            end
        end
        % Add additional patches for the two alternative timing cases
        switch comparatorModel
            case 'Ant10qtr'
                p=patch([1 9 9 1],...
                    [yLimits(1) yLimits(1) yLimits(2) yLimits(2)],'c');
                set(p,'FaceAlpha',0.1);
            case 'Ant20qtr'
                p=patch([1 19 19 1],...
                    [yLimits(1) yLimits(1) yLimits(2) yLimits(2)],'c');
                set(p,'FaceAlpha',0.1);
        end
        % Baseline timing patch
        p = patch(basePatchDateInfo,...
            [yLimits(1) yLimits(1) yLimits(2) yLimits(2)],'c');
        set(p,'FaceAlpha',0.2);
        hold off;
        grid on;
        box on;
        % Increase variable counter
        varCount = varCount + 1;
        % Apply xticks if needed
        if overWriteTicks
            set(gca,'XTick',tickMarks);
        end
        % Apply font size
        set(gca,'FontSize',fontSize);
    end
    % Add legend
    legHandles{iFig} = legend(legendStrings);
    legend boxoff;
end

%% SAVE FIGURES
if saveFigures
    for iFig = 1:nFigures
        iFigHandle = figHandles{iFig,1};
        adjx = 0.5;
        adjy = 0;
        set(iFigHandle,'PaperUnits','inches','PaperSize',(figDims(3:4)),...
            'PaperPosition',[-adjx -adjy figDims(3:4)+[adjx*1.5 adjy]]);
        % Fix legend placement
        iLegHandle = legHandles{iFig};
        iLegHandle.Orientation = 'horizontal';
        iLegHandle.FontSize = fontSize;
        legPosition = iLegHandle.Position;
        if plotForSlides
            legPosition(2) = 0.0125;
        else
            legPosition(2) = 0.05;
        end
        legPosition(1) = 0.5 - legPosition(3)/2;
        iLegHandle.Position = legPosition;
        iFigFileName = [figurePath 'BrexitSim' figStub '_Part' ...
            num2str(iFig) slidesStub '.pdf'];
        print(iFigHandle,iFigFileName,'-dpdf');
    end
end

end

