% Dynare file for Brexit simulations for the paper 
% "The Brexit Vote, Productivity Growth and Macroeconomic Adjustments in the United Kingdom"
% by Ben Broadbent, Federico Di Pace, Thomas Drechsel, Richard Harrison and Silvana Tenreyro

var pc p Psi nAgg cc ct cn kn kt rkt rkn yt yn y n nn nt wn wt bf bf_y rf rh tb 
    iv ivn ivt rf_ann rh_ann rfWorld rWorldAnn gan gat gazn gazt an at 
    s mu eps nu iota gaztPersist gaznPersist betaEndog
	rhLongAgg rfLongAgg rhLongAnn rfLongAnn;
    
varexo gaznshk gaztshk anshk atshk sshk mushk nushk epsshk iotshk;

parameters cbeta csigma cgamma comegat comegan cthetat cthetan cphit cphin 
    calpt calpn calphton cioy ccoy cgoy cgyn cgat cgan cgazt cgazn cdeltat cdeltan 
    czeta ctby cnt cnn cvsgan cvsgat cvsat cvsan cvsgv cvsmu cvsnu 
    cvseps cvsiot cvrgan cvrgat cvran cvrat cvrgv cvrmu cvreps cvrnu cvriot crf 
    vartheta can rhoPersist cbf cpsi cpsiBeta;  
    
parameters pc_ss p_ss Psi_ss nAgg_ss cc_ss ct_ss cn_ss kn_ss kt_ss rkt_ss 
    rkn_ss yt_ss yn_ss y_ss n_ss nn_ss nt_ss wn_ss wt_ss bf_ss bf_y_ss rf_ss 
    rh_ss tb_ss iv_ss ivn_ss ivt_ss rf_ann_ss rh_ann_ss rfWorld_ss rWorldAnn_ss gan_ss 
    gat_ss gazn_ss gazt_ss gaztPersist_ss gaznPersist_ss 
    an_ss at_ss s_ss mu_ss eps_ss iota_ss nu_ss betaEndog_ss
	nLongBondPeriods;

parameters pc_init p_init Psi_init nAgg_init cc_init ct_init cn_init kn_init 
   kt_init rkt_init rkn_init yt_init yn_init y_init n_init nn_init nt_init 
   wn_init wt_init bf_init bf_y_init rf_init rh_init tb_init iv_init ivn_init
   ivt_init rf_ann_init rh_ann_init rfWorld_init rWorldAnn_init gan_init gat_init 
   gazn_init gazt_init gaztPersist_init gaznPersist_init an_init 
  	at_init s_init mu_init eps_init iota_init nu_init betaEndog_init;    
    
%% -----------------------------------------------------------------------
% PARAMETERS



@# include "setShockInfo.mod"

% For long bonds
@#define nBondPeriods = 39
nLongBondPeriods = 40;

% Parameters that select debt elastic risk premium as method for closing SOE model
vartheta = 0;
cpsiBeta = 0;

%-------------------------------------------------------------------------
% 2.2.1 Estimated
%-------------------------------------------------------------------------
crf = 0.01;
cgat = 1.004;
cgan = 1.003;
cnt = 1.1;
cnn = cnt*(1-0.42)/0.42;
cbeta = 1/((1+crf)*cgat^(-cgamma));
cdeltat = 0.006;
cdeltan = 0.006;
cioy = 0.192;
ccoy = 0.644;
ctby = 0;
cpsi = 0.1/20000;

DlogPA = 0.01;
SE_OBS_DlogYN_NN = 0.0054;
SE_OBS_DlogYT_NT = 0.0065;
SE_OBS_Robs1 = 0.0018;
SE_OBS_Robs2 = 0.0017;
cgamma = 1.9944;
calphton = 1.301;
comegat = 2.5476;
comegan = 2.6458;
czeta = 0.6127;
cphit = 14.133;
cphin = 12.2789;
csigma = 0.6781;
cvsgan = 1; % 0.013;  % NORMALISATION (FOR NT PROD SIM FOR APPENDIX)
cvsgat = 1; % 0.0123; % NORMALISATION
cvsgv = 0.02;
cvsmu = 0.008;
cvsnu = 0.0269;
cvsat = 1; % 0.0124;  % NORMALISATION FOR LEVEL SHOCK VARIANT
cvsan = 0.0125;
cvseps = 0.0169;
cvrgan = 0.8; % 0.3741; % NORMALISATION FOR NT PROD SIM
cvrgat = 0.8; % 0.2332; % NORMALISATION
cvrgv = 0.5819;
cvrmu = 0.5561;
cvrnu = 0.9249;
cvran = 0.9077;
cvrat = 0.9045;
cvreps = 0.9488;

cvriot = 0.9316;
cvsiot = 0.0191;

%% -------------------------------------------------------------------------------------------
% COMPUTE STEADY STATE QUANTITIES
p_ss = 1;
pc_ss = (czeta+(1-czeta)*p_ss^(csigma/(csigma+1)))^((csigma+1)/csigma);
cbeta = 1/((1+crf)*cgat^(-cgamma));
nn_ss = cnn;
nt_ss = cnt;
rf_ss = crf;
rh_ss = rf_ss;
rfWorld_ss = rf_ss;
rWorldAnn_ss = 4*rf_ss;
rf_ann_ss = 4*rf_ss;
rh_ann_ss = 4*rh_ss;
gazt_ss = cgat;
cgazt = cgat;
gat_ss = cgat;
gan_ss = cgan;
rkt_ss=1+rf_ss-(1-cdeltat);
rkn_ss=1+rh_ss-(1-cdeltan); 
cgoy = 1 - cioy - ctby - ccoy;
ytoy = czeta*ccoy + czeta*cioy + ctby;
ynoy = (1-czeta)*ccoy + (1-czeta)*cioy + cgoy;
calpn = cioy/(calphton*ytoy/rkt_ss*(cgat-(1-cdeltat)) + ynoy/rkn_ss*(cgat-(1-cdeltan)));
calpt = calphton*calpn;
yt_ss = (calpt/rkt_ss)^(calpt/(1-calpt))*gat_ss*nt_ss;
y_ss = yt_ss/ytoy;
yn_ss = ynoy*y_ss;
gazn_ss = (cgan/(cgat^(calpn)))^(1/(1-calpn));
cgazn = gazn_ss;
can = (yn_ss/(gazn_ss*nn_ss))^(1-calpn)*(rkn_ss/calpn)^calpn;
kt_ss = calpt*yt_ss/rkt_ss;
kn_ss = calpn*yn_ss/rkn_ss;
cc_ss = ccoy*y_ss;
iv_ss = cioy*y_ss;
cgyn = cgoy*y_ss/yn_ss;
ivt_ss = czeta*iv_ss;
ivn_ss = (1-czeta)*iv_ss;
ct_ss = czeta*cc_ss;
cn_ss = (1-czeta)*cc_ss;
wt_ss = (1-calpt)*yt_ss/nt_ss;
wn_ss = (1-calpn)*yn_ss/nn_ss;
cc_ss = (czeta^(1+csigma)*ct_ss^(-csigma)+(1-czeta)^(1+csigma)*cn_ss^(-csigma))^(-1/csigma);
cbf = ctby*y_ss*(1+rf_ss)/((1+rf_ss)-gat_ss);
bf_ss = cbf;
tb_ss = ctby*y_ss;
bf_y_ss = bf_ss/y_ss;
iv_ss = ivt_ss+p_ss*ivn_ss;
cthetan = wn_ss*(1-czeta)^(1+csigma)*(cn_ss/cc_ss)^(-csigma-1)/(nn_ss^(comegan-1));
cthetat = wt_ss*czeta^(1+csigma)*(ct_ss/cc_ss)^(-csigma-1)/(nt_ss^(comegat-1));
n_ss = nn_ss + nt_ss;
y_ss = yt_ss + yn_ss*p_ss;
nAgg_ss = (cthetat*(wt_ss/(cthetat*pc_ss))^(comegat/(comegat-1))/comegat + cthetan*(wn_ss/(cthetan*pc_ss))^(comegan/(comegan-1))/comegan);
mathB = gat_ss*(1-vartheta*bf_ss/(pc_ss*(cc_ss-nAgg_ss)))/((1+vartheta)*(1-vartheta*cgat*bf_ss/((1+vartheta)*(1+rf_ss)*pc_ss*(cc_ss-nAgg_ss))));
cbeta = mathB^cgamma/(1+rf_ss);
Psi_ss = 1/(1-cbeta^(1/cgamma)*(1+rf_ss)^(1/cgamma-1));
gaztPersist_ss = cgazt;
gaznPersist_ss = cgazn;
an_ss = 1;
at_ss = 1;
s_ss = 1;
mu_ss = 1;
eps_ss = 1;
iota_ss = 1;
nu_ss = 1;
betaEndog_ss = cbeta;
rhLongAgg_ss = (1+rh_ss)^nLongBondPeriods;
rfLongAgg_ss = (1+rf_ss)^nLongBondPeriods;
rhLongAnn_ss = (1+rh_ss)^4 - 1;
rfLongAnn_ss = (1+rf_ss)^4 - 1;

pc_init = pc_ss;
p_init = p_ss;
Psi_init = Psi_ss;
nAgg_init = nAgg_ss;
cc_init = cc_ss; 
ct_init = ct_ss; 
cn_init = cn_ss; 
kn_init = kn_ss; 
kt_init = kt_ss; 
rkt_init = rkt_ss; 
rkn_init = rkn_ss; 
yt_init = yt_ss; 
yn_init = yn_ss; 
y_init = y_ss; 
n_init = n_ss; 
nn_init = nn_ss; 
nt_init = nt_ss; 
wn_init = wn_ss; 
wt_init = wt_ss; 
bf_init = bf_ss; 
bf_y_init = bf_y_ss; 
rf_init = rf_ss; 
rh_init = rh_ss; 
tb_init = tb_ss; 
iv_init = iv_ss;
ivn_init = ivn_ss;
ivt_init = ivt_ss;
rf_ann_init = rf_ann_ss; 
rh_ann_init = rh_ann_ss; 
rfWorld_init = rfWorld_ss;
rWorldAnn_init = rWorldAnn_ss;
gan_init = gan_ss; 
gat_init = gat_ss;
gazn_init = gazn_ss; 
gazt_init = gazt_ss; 
gaztPersist_init = gaztPersist_ss;
gaznPersist_init = gaznPersist_ss;
an_init = 1;
at_init = 1;
s_init = 1;
mu_init = 1;
eps_init = 1;
iota_init = 1;
nu_init = 1;
betaEndog_init = betaEndog_ss;
rhLongAgg_init = rhLongAgg_ss;
rfLongAgg_init = rfLongAgg_ss;
rhLongAnn_init= rhLongAnn_ss;
rfLongAnn_init = rfLongAnn_ss;

%% ------------------------------------------------------------------------
% DECLARE MODEL

model(bytecode);

    [name='Consumption Aggregator', eq='#1']                                
    cc^(-csigma)=(czeta^(1+csigma)*ct^(-csigma)+(1-czeta)^(1+csigma)*cn^(-csigma));
    [name='Aggregate Euler equation', eq='#2']                              
    pc*(cc - nAgg) = (pc(+1)/pc)^((1-cgamma)/cgamma)*(betaEndog*(1+rf))^(-1/cgamma)*gat/(1+vartheta)
    					*pc(+1)*(cc(+1) - nAgg(+1)) 
    					- vartheta*gat/(1+vartheta)*bf/((Psi - 1)*(1+rf));   
    [name='T vs composite bond returns', eq='#3']                           
    pc=(1+rh)/(1+rf)*pc(+1);
    [name='Disutility of Labour', eq='#4']                                  
    nAgg = 1/comegat*cthetat*nt^comegat + 1/comegan*cthetan*nn^comegan;     
    [name='Disutility of Labour', eq='#5']                                  
    Psi = 1 + betaEndog^(1/cgamma)*(pc(+1)/(pc*(1+rf)))^(1-1/cgamma)*Psi(+1); 
    [name='MRS in consumption', eq='#6']                                    
    p = (cn/ct*czeta/(1-czeta))^(-csigma-1);                             
    [name='Labour optimality condition in $T$', eq='#7']                    
    nt = (wt/(cthetat*pc))^(1/(comegat-1));                                 
    [name='Labour optimality condition in $T$', eq='#8']                    
    nn = (wn/(cthetan*pc))^(1/(comegan-1));                                 
    [name='Interest rate of foreign bonds - 1', eq='#9']                    
    rf = rfWorld;                                                           
    [name='Interest rate of foreign bonds - 2', eq='#10']                   
    rfWorld = crf+(exp(mu-1)-1)+cpsi*(bf-cbf);                                                                       
    [name='Endogeneous discount factor - if active', eq='#11']              
    betaEndog = cbeta*exp(cpsiBeta*(bf-cbf));                            
    [name='Debt to GDP ratio', eq='#12']                                    
    bf_y = bf/y;                                                            
    [name='Euler equation in $T$ capital', eq='#13']                         
    (1+rf)*(pc/pc(+1))*(iota(+1)/iota)*(1+cphit*(kt/kt(-1)*gat-cgat)) =
           (iota(+1)/pc(+1)*rkt(+1)+(1-cdeltat)
           + cphit*(kt(+1)/kt*gat(+1)-cgat)*(kt(+1)/kt)*gat(+1) 
           - cphit/2*(kt(+1)/kt*gat(+1)-cgat)^2);                                                 
    [name='Euler equation in $N$ capital', eq='#14']                        
    (1+rf)*pc/pc(+1)*(iota(+1)/iota)*(1+cphin*(kn/kn(-1)*gat-cgat)) =
            (iota(+1)/pc(+1)*rkn(+1)+(1-cdeltan)
            + cphin*(kn(+1)/kn*gat(+1)-cgat)*(kn(+1)/kn)*gat(+1) 
            - cphin/2*(kn(+1)/kn*gat(+1)-cgat)^2);                                                    

%-------------------------------------------------------------------------
% 3.2 Firms
%-------------------------------------------------------------------------
    [name='Production function $T$', eq='#15']
    yt=at*kt(-1)^calpt*(gazt*nt)^(1-calpt);                                                      
    [name='Production function $N$', eq='#16']
    yn=an*kn(-1)^calpn*(gazn*nn)^(1-calpn);                                                      
    [name='Marginal product of capital in $T$', eq='#17']
    rkt=calpt*at*kt(-1)^(calpt-1)*(gazt*nt)^(1-calpt);                                           
    [name='Marginal product of capital in $N$', eq='#18']
    rkn=p*calpn*an*kn(-1)^(calpn-1)*(gazn*nn)^(1-calpn);                                           
    [name='Marginal product of labour in $T$', eq='#19']
    wt=(1-calpt)*at*gazt^(1-calpt)*kt(-1)^calpt*nt^(-calpt);                                     
    [name='Marginal product of labour in $N$', eq='#20']
    wn=p*(1-calpn)*an*gazn^(1-calpn)*kn(-1)^calpn*nn^(-calpn);   
    
%-------------------------------------------------------------------------
% 3.2 Resource Cosntraints and Definitions
%-------------------------------------------------------------------------
    [name='Resource constraint in $T$', eq='#21']                           
    yt = ct+czeta*iv*(pc)^(1/(1+csigma))+tb+pc/iota*cphit/2*(kt/kt(-1)*gat-cgat)^2*kt(-1);                                
    [name='Resource constraint in $N$', eq='#22']                           
    yn*(1-cgyn*s)=cn+(1-czeta)*iv*(pc/p)^(1/(1+csigma))+(pc/(iota*p))*cphin/2*(kn/kn(-1)*gat-cgat)^2*kn(-1);                  
    [name='Growth rate in T', eq='#23']                                     
    gat = gazt;                                                                                    
    [name='Growth rate in N', eq='#24']                                     
    gan = gat^calpn*gazn^(1-calpn);   
    [name='Net foreign asset position', eq='#25']                            
    bf(-1) - bf/((1+rf))*gat=tb*(1+vartheta);                                           
    [name='Definition of output', eq='#26']                                 
    y = yt+p*yn;                                                                             
    [name='Definition of investment', eq='#27']                             
    iv = 1/iota*(kt*gat-(1-cdeltat)*kt(-1)+kn*gat-(1-cdeltan)*kn(-1));                             
    [name='Consumption Price in terms of T goods', eq='#28']                
    pc = (czeta+(1-czeta)*p^(csigma/(1+csigma)))^((1+csigma)/(csigma));     
    [name='Total hours', eq='#29']                                          
    n = nt+nn;
    [name='Total hours', eq='#30']
    ivt = czeta*iv*(pc)^(1/(1+csigma));
    [name='Total hours', eq='#31']
    ivn = (1-czeta)*iv*(pc/p)^(1/(1+csigma));
    [name='Foreign Annual Rate', eq='#32']                                  
    rf_ann = 4*rf;                                                            
    [name='Domestic Annual Rate', eq='#33']                                 
    rh_ann = 4*rh;                                                            
    [name='Interest rate of foreign bonds - 3', eq='#34']                   
    rWorldAnn = 4*rfWorld;     
    
	rhLongAgg = (1+rh)
		@#for idx in 1:nBondPeriods
		*(1+rh(@{idx}))
		@#endfor
		;

	1 + rhLongAnn = rhLongAgg^(4/nLongBondPeriods);


	rfLongAgg = (1+rf)
		@#for idx in 1:nBondPeriods
		*(1+rf(@{idx}))
		@#endfor
		;
    
	1 + rfLongAnn = rfLongAgg^(4/nLongBondPeriods);
	
	
%-------------------------------------------------------------------------
% 3.10 Shocks
%-------------------------------------------------------------------------   
% 3.10.1 Structural Shocks
%-------------------------------------------------------------------------
    [name='Government expenditure shock', eq='#35']                         
    s=s(-1)^cvrgv*exp(cvsgv*sshk);
    [name='Foreign interest rate shock', eq='#36']                          
    mu=mu(-1)^cvrmu*exp(cvsmu*mushk);
    [name='Temporary TFP shock in $N$', eq='#37']                           
    (an/can)=(an(-1)/can)^cvran*exp(cvsan*anshk);
    [name='Temporary TFP shock in $T$', eq='#38']                           
    at=at(-1)^cvrat*exp(cvsat*atshk);
    [name='Discount fact shock', eq='#39']                                  
    nu=nu(-1)^cvrnu*exp(cvsnu*nushk);
    [name='Aggregate labour supply shock', eq='#40']                        
    eps=eps(-1)^cvreps*exp(cvseps*epsshk);
    [name='IST shock', eq='#41']                                            
    iota=iota(-1)^cvriot*exp(cvsiot*iotshk);                                
    
% Two main shocks for Brexit experiments
    [name='Growth rate shock in $T$ - 1', eq='#42']                         
	   gazt = gaztPersist^(1-cvrgat)*gazt(-1)^cvrgat;                       
    [name='Growth rate shock in $T$ - 2', eq='#43']                         
	    gaztPersist = gaztPersist(-1)^rhoPersist*cgazt^(1-rhoPersist)*exp(cvsgat*gaztshk/(1-cvrgat));
    [name='Growth rate shock in $N$ - 1', eq='#44']                         
        gazn = gaznPersist^(1-cvrgan)*gazn(-1)^cvrgan;          
    [name='Growth rate shock in $N$ - 2', eq='#45']                         
		gaznPersist = gaznPersist(-1)^rhoPersist*cgazn^(1-rhoPersist)*exp(cvsgan*gaznshk/(1-cvrgan));

end;

%% END OF MODEL BLOCK


%% --------------------------------------------------------
% DEFINE STEADY STATE MODEL
steady_state_model;
    gazn = cgazn;
    gazt = cgazt;
    gaztPersist = cgazt;
    gaznPersist = cgazn;
    gan = cgan;
    gat = cgat;
    rf = crf;
    rh = crf;
    rfWorld = crf;
    rWorldAnn = 4*crf;
    rf_ann = 4*crf;
    rh_ann = 4*crf;
    rkt = rkt_ss;
    rkn = rkn_ss; 
    wt = wt_ss;
    wn = wn_ss;
    p = p_ss;
    nn = nn_ss;
    nt = nt_ss;
    cn = cn_ss;
    ct = ct_ss;
    kt = kt_ss;
    kn = kn_ss;
    yn = yn_ss;
    yt = yt_ss;
    bf = bf_ss; 
    tb = tb_ss;
    cc = cc_ss;
    bf_y = bf_y_ss;
    iv = iv_ss;
    ivn = ivn_ss;
    ivt = ivt_ss;
    n = n_ss;
    s = 1;
    eps = 1;
    mu = 1;
    nu = 1;
    at = 1;
    iota = 1;
    an = can;
    y = y_ss;
    pc = pc_ss;
    nAgg = nAgg_ss;
    betaEndog = cbeta;
    Psi = 1/(1-betaEndog^(1/cgamma)*(1+rf)^(1/cgamma-1));
	rhLongAgg = (1+rh)^nLongBondPeriods;
	rfLongAgg = (1+rf)^nLongBondPeriods;
	rhLongAnn = (1+rh)^4-1;
	rfLongAnn = (1+rf)^4-1;
end;

%% ----------------------------------------------------
% STEADY STATE

steady;

% CHECK EIGENVALUES
check;

%% ----------------------------------------------------
% Initialise deterministic simulation

initval;
	pc = pc_ss; 
	Psi = Psi_ss;
	nAgg = nAgg_ss;
 	cc = cc_ss;
   	ct = ct_ss;
   	cn = cn_ss;
   	kn =kn_ss;
   	kt = kt_ss;
   	rkt = rkt_ss;
   	rkn = rkn_ss;
   	yt = yt_ss;
   	yn = yn_ss;
   	y = y_ss;
   	p = p_ss;
   	n = n_ss;
   	nn = nn_ss;
   	nt = nt_ss;
   	wn = wn_ss;
   	wt = wt_ss;
   	bf = bf_ss;
   	rf = rf_ss;
   	rh = rh_ss;
   	tb = tb_ss;
   	iv = iv_ss;
    ivt = ivt_ss;
    ivn = ivn_ss;
   	rf_ann = rf_ann_ss;
   	rh_ann = rh_ann_ss;
   	rfWorld = rfWorld_ss;
   	rWorldAnn = rWorldAnn_ss;
   	bf_y = bf_y_ss;
   	gazn = gazn_ss;
   	gazt = gazt_ss;
    gan = gan_ss;
   	gat = gat_ss;
   	an = an_ss;
   	at = at_ss;
   	s = s_ss;
   	mu = mu_ss;
   	eps = eps_ss;
    iota = iota_ss;
   	nu = nu_ss;
   	gaztPersist = gaztPersist_ss;
	gaznPersist = gaznPersist_ss;
    betaEndog = betaEndog_ss;
	rhLongAgg = rhLongAgg_ss;
	rfLongAgg = rhLongAgg_ss;
	rhLongAnn = rhLongAnn_ss;
	rfLongAnn = rfLongAnn_ss;
end;


%% -------------------------------------------------------
% DETERMINISTIC SIMULATION

% Control shock specification using info loaded at start

switch shockVariant
	case 'baseline'
		shocks;
		var gaztshk; periods 15; values -0.000530;                          % Baseline expt
		end;
	case 'LessPersistent'
		shocks;
			var gaztshk; periods 15; values -0.00106;                         % For less persistent variant
		end;
	case 'Ant20qtr'
		shocks;
			var gaztshk; periods 20; values -0.000530;                          % Later anticipation variant
		end;		
    case 'Ant10qtr'
		shocks;
			var gaztshk; periods 10; values -0.000530;                           % Early anticipation variant
		end;
	case 'gaNshock'
		shocks;
			var gaznshk; periods 15; values 0.0007;                           % Non-traded TFP growth shock
		end;	
	case 'LevelShock'
		shocks;
			var atshk; periods 15; values -0.129330024810320;                         % Traded TFP level shock
		end;
	
otherwise
	error('shockVariant not supported');
    end

options_.pfsf=1;
options_.dynatol.f   = 1e-10;
options_.periods     = 8000;  
options_.simul.maxit = 800;
simul(stack_solve_algo = 4); 