% Script to produce plots of Brexit simulation variants

%% WORKSPACE AND PATH MANAGEMENT
tidyUpAndSetPath;
startTime = clock;

%% OPTIONS
saveFigures = true;
comparatorList = {'none';'Ant10qtr';'Ant20qtr';'LessPersistent';...
    'LevelShock';'gaNshock'};

plotOptions = struct;
plotOptions.nPreShockPeriods = 0;
plotOptions.nPostShockPeriods = 32;
plotOptions.fontSize = 12;
plotOptions.tickGap = 8;
plotOptions.plotForSlides = false;

%% DETRENDING LOOKUP TABLE
varDetrendingInfo = ...
          {'yt', 'logLevel100', 'T';
           'yn', 'logLevel100', 'N';
           'ct', 'logLevel100', 'T';
           'cn', 'logLevel100', 'N';
           'wt', 'logLevel100', 'T';
           'wn', 'logLevel100', 'N';
           'p', 'logLevel100', 'ToverN';
           'tb_y','TBratio', {'yt';'yn';'tb';'p'};
           'GDP', 'ChainLinked', {'yt';'yn';'p'};
           'c', 'ChainLinked', {'ct';'cn';'p'};
           'iv', 'ChainLinked', {'ivt';'ivn';'p'};
           'I_Y', 'RatioToOutput', {'yt';'yn';'p';'pc';'iv'};
           'gat', 'minus1times400', 'gat';
            'spreads', 'RateDifference', {'rhLongAnn';'rfLongAnn'};
            'spreadsShort', 'RateDifference', {'rh_ann';'rf_ann'};
           'nn', 'logLevel100devFromTrend', '';
           'nt', 'logLevel100devFromTrend', '';
           'n', 'logLevel100devFromTrend', '';
           'modelTB_y','TBproxyDevFromTrend',{'yt';'yn';'ct';'ivt';'p'};
            'wav','AverageLogLevel100',{'wt';'wn';'nt';'nn'}};

%% VARIABLES TO BE PLOTTED
plotVarInfo = {'gat','Tradable sector productivity growth rate';
    'GDP','Chain-linked GDP (100*log)';
    'yt','Tradable sector output (100*log)';
    'yn','Non-tradable sector output (100*log)';
    'p','Relative price of non-tradable output (100*log)';
    'spreadsShort','Domestic bond spread (annualized %)';
    'n','Total hours worked (100*log)';
    'iv','Chain-linked investment (100*log)';
    'modelTB_y','Trade balance/output (%)';
    'c','Chain-linked consumption (100*log)';
    'ct','Tradable sector consumption (100*log)';
    'cn','Non-tradable sector consumption (100*log)';
    'nt','Hours worked, tradable sector (100*log)';
    'nn',' Hours worked, non-tradable sector (100*log)';
    'wt','Tradable sector wage (100*log)';
    'wn','Non-tradable sector wage (100*log)'};

%% RUN THE FUNCTION      
nComparators = size(comparatorList,1);
for iComparator = 1:nComparators
    iCompName = comparatorList{iComparator};
    figHandles = plot_simulation_results(iCompName,plotVarInfo,...
        varDetrendingInfo,figureFolder,saveFigures,resultsFolder,...
        plotOptions);
end

%% DISPLAY TOTAL COMPUTATION TIME
finishTime = clock;
disp('*********************************************************');
disp('TOTAL COMPUTING TIME FOR ALL VARIANTS:');
compute_and_display_elapsed_time(startTime,finishTime);
