% Script to plot Figure 1 in the paper.

%% PATH AND WORKSPACE MANAGEMENT
tidyUpAndSetPath;

%% OPTIONS
estimationDataFile = [dataFolder 'selectedDataSeries.xlsx'];
saveFigure = true;
nPreRefPeriods = 8; 
% De-trending approach
detrendingInfo = struct;
detrendingInfo.detrendStartDate = 71;
periodZero = 78; % June 2016 is row 79 in s/sheet (-1 to account for loss of header)
detrendingInfo.detrendEndDate = periodZero;
detrendingInfo.detrendType = 'linear';
% Variables for the panels
varMnems = {'p';'yt';'yn';'GDP'};
varNames = {'Relative price of nontraded output';...
    'Tradable output';'Nontradable output'};
% Colours
newBlue = [0,0.447,0.741];
newRed = [0.85,0.325,0.098];
newOrange = [ 0.9100 0.4100 0.1700];

%% LOAD DATA
[data,dataNames] = xlsread(estimationDataFile,'PlotsLong','B1:M93');
%[~,dateStrings] = xlsread(estimationDataFile,'PlotsLong','A2:A93');
dateNums = xlsread(estimationDataFile,'PlotsLong','A2:A93');
detrendedSeries = extract_full_sample_detrended_data(data,...
        dataNames',varMnems,detrendingInfo);
    
%% PREPARE DATE LABELING
nVars = size(varMnems,1);
plotHorizon = (periodZero-nPreRefPeriods):size(data,1);
plotPeriods = 0:(length(plotHorizon)-1);
tickGap = 4;
tickPeriods = plotPeriods(1):tickGap:plotPeriods(end);
tickLabelPeriods = plotHorizon(1):tickGap:plotHorizon(end);

dateNums = x2mdate(dateNums);
tickLabelsRaw = dateNums(tickLabelPeriods);
nLabels = size(tickLabelsRaw,1);
tickLabels = cell(nLabels,1);
for iLabel = 1:nLabels
    tickLabels{iLabel} = datestr(tickLabelsRaw(iLabel),'YYQQ');
end

%% COMPUTE SERIES TO PLOT
ytSeries = detrendedSeries.yt.rawData(plotHorizon) - ...
        detrendedSeries.yt.rawData(periodZero);
ynSeries = detrendedSeries.yn.rawData(plotHorizon) - ...
        detrendedSeries.yn.rawData(periodZero);
pSeries = detrendedSeries.p.rawData(plotHorizon) - ...
        detrendedSeries.p.rawData(periodZero);
pTrend = detrendedSeries.p.trend(plotHorizon) - ...
        detrendedSeries.p.trend(periodZero);
gdpSeries = detrendedSeries.GDP.rawData(plotHorizon) - ...
        detrendedSeries.GDP.rawData(periodZero);

%% CREATE THE FIGURE    
twoPanelFigHandle = figure;
subplot(1,2,1);
hold on;
plot(plotPeriods,100+gdpSeries,'color',newBlue,'linewidth',2);
plot(plotPeriods,100+ytSeries,'color',newRed,'linestyle','-.','linewidth',2);
plot(plotPeriods,100+ynSeries,'color',newOrange,'linestyle',':',...
    'linewidth',2);
iylim = get(gca,'Ylim');
set(gca,'XTick',tickPeriods,'XTickLabel',tickLabels);
xlim([plotPeriods(1) plotPeriods(end)]);    
antPhase = patch([nPreRefPeriods+1 plotPeriods(end) plotPeriods(end) nPreRefPeriods+1],...
    [iylim(1) iylim(1) iylim(2) iylim(2)],'c');        
antPhase.FaceAlpha = 0.2;
leftLegHandle = ...
    legend('GDP','Tradable GVA','Non-tradable GVA','Location','NorthWest');
legend boxoff;
title('A: GDP and sectoral GVA');
grid on;
box on;
subplot(1,2,2);
hold on;
plot(plotPeriods,100+pSeries,'color',newBlue,'linewidth',2);

plot(plotPeriods,100+pTrend,'k--','linewidth',2);
ylim(iylim);
antPhase = patch([nPreRefPeriods+1 plotPeriods(end) plotPeriods(end) nPreRefPeriods+1],...
    [iylim(1) iylim(1) iylim(2) iylim(2)],'c');        
antPhase.FaceAlpha = 0.2;
set(gca,'XTick',tickPeriods,'XTickLabel',tickLabels);
xlim([plotPeriods(1) plotPeriods(end)]);    
title('B: Relative price of non-tradable GVA');
grid on;
box on;

%% SAVE FIGURE
if saveFigure
    figDims = [12 5.5]*0.75;
    adjx = 0.5;
    adjy = 0;
    set(twoPanelFigHandle,'PaperUnits','inches',...    
        'PaperSize',(figDims),...
        'PaperPosition',[-adjx -adjy figDims+[adjx*1.5 adjy]]);
    leftLegHandle.Orientation = 'horizontal';
    legPosition = leftLegHandle.Position;
    legPosition(2) = 0; 
    legPosition(1) = 0.015; 
    leftLegHandle.Position = legPosition;
    print(twoPanelFigHandle,'-dpdf',[figureFolder 'Figure1.pdf']);
end



    